Package 'OSCA.basic'

Title: Single-Cell Analysis Basics
Description: Deploys basic analysis chapters for the "Orchestrating Single Cell Analysis with Bioconductor" book. This describes the steps of a simple single-cell RNA-seq analysis, involving quality control, normalization, various forms of dimensionality reduction, clustering into subpopulations, detection of marker genes, and annotation of cell types. It is intended for users who already have some familiarity with R and want to get hands-on with some basic single-cell analyses.
Authors: Robert Amezquita [aut], Aaron Lun [aut], Stephanie Hicks [aut], Raphael Gottardo [aut], Peter Hickey [cre]
Maintainer: Peter Hickey <[email protected]>
License: CC BY 4.0
Version: 1.21.0
Built: 2026-05-28 15:00:52 UTC
Source: https://github.com/bioc/OSCA.basic

Help Index